import { Box } from '@chakra-ui/core'
import { Physics } from '@react-three/cannon'
import { PointerLockControls, Sky } from '@react-three/drei'
import { Environment } from '@react-three/drei/Environment'
import {
  Bloom,
  DepthOfField,
  EffectComposer,
  Vignette,
} from '@react-three/postprocessing'
import React, { Suspense } from 'react'
import { Canvas } from 'react-three-fiber'
import Plaza from '../models/Plaza'
import PlazaCollision from '../models/Plaza_collision'
import Player from './Player'

const Museo: React.FC = () => {
  return (
    <Box w="100vw" h="100vh">
      <Canvas colorManagement>
        <ambientLight color={0xd3840e} />
        <pointLight position={[0, 20, -30]} color={0xd3840e} />
        <Suspense fallback={null}>
          <Plaza />
          <Physics
            gravity={[0, 0, 0]}
            iterations={10}
            step={1 / 60}
            size={10}
            broadphase="SAP"
            axisIndex={1}
            defaultContactMaterial={{
              friction: 0,
              restitution: 0,
            }}
          >
            <PlazaCollision />
            <Player />
          </Physics>
        </Suspense>
        <Sky
          distance={550000}
          azimuth={0.25}
          mieDirectionalG={0.83}
          mieCoefficient={0.008}
          inclination={0.5}
          turbidity={8}
          rayleigh={2.9}
        />
        <Suspense fallback={null}>
          <EffectComposer>
            <DepthOfField
              focusDistance={0}
              focalLength={0.15}
              bokehScale={2}
              height={480}
            />
            <Vignette eskil={false} offset={0.1} darkness={0.8} />
            <Bloom
              luminanceThreshold={0.7}
              luminanceSmoothing={0.9}
              height={300}
              opacity={3}
            />
          </EffectComposer>
        </Suspense>
        <PointerLockControls />
      </Canvas>
    </Box>
  )
}

export default Museo
